@@ -35,7 +35,7 @@ private:
     AssociatedFilesUI *p;
 
 public:
-    QLabel *labelGreeting, *labelFollowingOperations;
+    QLabel *labelGreeting;
     KLineEdit *lineEditSourceUrl;
     QRadioButton *radioNoCopyMove, *radioCopyFile, *radioMoveFile;
     QLabel *labelMoveCopyLocation;
@@ -201,6 +201,11 @@ AssociatedFilesUI::AssociatedFilesUI(const QString &entryId, const File *bibTeXf
     d->bibTeXfile = bibTeXfile;
 }
 
+AssociatedFilesUI::~AssociatedFilesUI()
+{
+    delete d;
+}
+
 AssociatedFiles::RenameOperation AssociatedFilesUI::renameOperation() const {
     if (d->radioRenameToEntryId->isChecked())
         return AssociatedFiles::roEntryId;
