@@ -51,7 +51,24 @@ public:
             : p(parent), isReadOnly(false), percent(-1.0), maxNumberOfStars(mnos),
           unsetStarsText(i18n("Not set"))
     {
-        /// nothing
+        QHBoxLayout *layout = new QHBoxLayout(p);
+        spacing = qMax(layout->spacing(), 8);
+        layout->setContentsMargins(0, 0, 0, 0);
+
+        labelPercent = new QLabel(p);
+        layout->addWidget(labelPercent, 0, Qt::AlignRight | Qt::AlignVCenter);
+        QFontMetrics fm(labelPercent->fontMetrics());
+        labelPercent->setFixedWidth(fm.width(unsetStarsText));
+        labelPercent->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+        labelPercent->setText(unsetStarsText);
+        labelPercent->installEventFilter(parent);
+
+        layout->addStretch(1);
+
+        clearButton = new KPushButton(KIcon("edit-clear-locationbar-rtl"), QString(), p);
+        layout->addWidget(clearButton, 0, Qt::AlignRight | Qt::AlignVCenter);
+        connect(clearButton, SIGNAL(clicked()), p, SLOT(clear()));
+        clearButton->installEventFilter(parent);
     }
 
     QRect starsInside() const
@@ -60,7 +77,7 @@ public:
         return QRect(QPoint(labelPercent->width() + spacing, (p->height() - starRectHeight) / 2), QSize(p->width() - 2 * spacing - clearButton->width() - labelPercent->width(), starRectHeight));
     }
 
-    float percentForPosition(const QPoint &pos, int numTotalStars, const QRect &inside)
+    float percentForPosition(const QPoint pos, int numTotalStars, const QRect inside)
     {
         const int starSize = qMin(inside.height() - 2 * Private::paintMargin, (inside.width() - 2 * Private::paintMargin) / numTotalStars);
         const int width = starSize * numTotalStars;
@@ -75,23 +92,6 @@ const int StarRating::Private::paintMargin = 2;
 StarRating::StarRating(int maxNumberOfStars, QWidget *parent)
         : QWidget(parent), d(new Private(maxNumberOfStars, this))
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    d->spacing = qMax(layout->spacing(), 8);
-    layout->setContentsMargins(0, 0, 0, 0);
-
-    d->labelPercent = new QLabel(this);
-    layout->addWidget(d->labelPercent, 0, Qt::AlignRight | Qt::AlignVCenter);
-    QFontMetrics fm(d->labelPercent->fontMetrics());
-    d->labelPercent->setFixedWidth(fm.width(d->unsetStarsText));
-    d->labelPercent->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    d->labelPercent->setText(d->unsetStarsText);
-
-    layout->addStretch(1);
-
-    d->clearButton = new KPushButton(KIcon("edit-clear-locationbar-rtl"), QString(), this);
-    layout->addWidget(d->clearButton, 0, Qt::AlignRight | Qt::AlignVCenter);
-    connect(d->clearButton, SIGNAL(clicked()), this, SLOT(clear()));
-
     QTimer::singleShot(250, this, SLOT(buttonHeight()));
 
     setMouseTracking(true);
@@ -157,6 +157,18 @@ void StarRating::leaveEvent(QEvent *ev)
     }
 }
 
+bool StarRating::eventFilter(QObject *obj, QEvent *event)
+{
+    if (obj != d->labelPercent && obj != d->clearButton)
+        return false;
+
+    if ((event->type() == QEvent::MouseMove || event->type() == QEvent::Enter) && d->mouseLocation != QPoint()) {
+        d->mouseLocation = QPoint();
+        update();
+    }
+    return false;
+}
+
 float StarRating::value() const
 {
     return d->percent;
@@ -175,6 +187,7 @@ void StarRating::setValue(float percent)
 void StarRating::unsetValue() {
     if (d->isReadOnly) return; ///< disallow modifications if read-only
 
+    d->mouseLocation = QPoint();
     d->percent = -1.0;
     update();
 }
@@ -201,7 +214,7 @@ void StarRating::buttonHeight()
     d->clearButton->setSizePolicy(sp.horizontalPolicy(), QSizePolicy::MinimumExpanding);
 }
 
-void StarRating::paintStars(QPainter *painter, KIconLoader::States defaultState, int numTotalStars, float percent, const QRect &inside)
+void StarRating::paintStars(QPainter *painter, KIconLoader::States defaultState, int numTotalStars, float percent, const QRect inside)
 {
     painter->save(); ///< Save the current painter's state; at this function's end restored
 
