@@ -70,7 +70,7 @@ public:
     const QString configGroupName, configGroupNameGeneral;
 
     FileExporterBibTeXPrivate(FileExporterBibTeX *parent)
-            : p(parent), cancelFlag(false), iconvLaTeX(NULL), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName("FileExporterBibTeX"), configGroupNameGeneral("General") {
+            : p(parent), keywordCasing(KBibTeX::cLowerCase), quoteComment(Preferences::qcNone), protectCasing(Qt::PartiallyChecked), cancelFlag(false), iconvLaTeX(NULL), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName("FileExporterBibTeX"), configGroupNameGeneral("General") {
         // nothing
     }
 
@@ -131,8 +131,8 @@ public:
     }
 
     bool writeEntry(QIODevice *iodevice, const Entry &entry) {
-        BibTeXEntries *be = BibTeXEntries::self();
-        BibTeXFields *bf = BibTeXFields::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXFields *bf = BibTeXFields::self();
         EncoderLaTeX *laTeXEncoder = EncoderLaTeX::instance();
 
         /// write start of a entry (entry type and id) in plain ASCII
@@ -155,7 +155,7 @@ public:
 
             // FIXME hack!
             const QSharedPointer<ValueItem> first = *value.constBegin();
-            if (typeid(*first) == typeid(PlainText) && (key == Entry::ftTitle || key == Entry::ftBookTitle || key == Entry::ftSeries)) {
+            if (PlainText::isPlainText(*first) && (key == Entry::ftTitle || key == Entry::ftBookTitle || key == Entry::ftSeries)) {
                 if (protectCasing == Qt::Checked)
                     addProtectiveCasing(text);
                 else if (protectCasing == Qt::Unchecked)
@@ -180,7 +180,7 @@ public:
     }
 
     bool writeMacro(QIODevice *iodevice, const Macro &macro) {
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
 
         QString text = p->internalValueToBibTeX(macro.value(), QString(), leUTF8);
         if (protectCasing == Qt::Checked)
@@ -204,7 +204,7 @@ public:
     }
 
     bool writeComment(QIODevice *iodevice, const Comment &comment) {
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
 
         QString text = comment.text() ;
 
@@ -220,11 +220,10 @@ public:
             QStringList commentLines = text.split('\n', QString::SkipEmptyParts);
             for (QStringList::Iterator it = commentLines.begin(); it != commentLines.end(); ++it) {
                 const QByteArray line = iconvLaTeX->encode(*it);
-                iodevice->putChar('%');
-                if (line.length() > 0 && line[0] != '%') {
-                    /// Avoid space in between if multiple percent signs are used
-                    /// at the beginning of a comment
-                    iodevice->putChar(' ');
+                if (line.length() == 0 || line[0] != QLatin1Char('%')) {
+                    /// Guarantee that every line starts with
+                    /// a percent sign
+                    iodevice->putChar('%');
                 }
                 iodevice->write(line);
                 iodevice->putChar('\n');
@@ -240,7 +239,7 @@ public:
     }
 
     bool writePreamble(QIODevice *iodevice, const Preamble &preamble) {
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
 
         iodevice->putChar('@');
         iodevice->write(be->format(QLatin1String("Preamble"), keywordCasing).toLatin1().data());
@@ -639,3 +638,7 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
 
     return result;
 }
+
+bool FileExporterBibTeX::isFileExporterBibTeX(const FileExporter &other) {
+    return typeid(other) == typeid(FileExporterBibTeX);
+}
