@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,8 +17,6 @@
 
 #include "fileexporterxml.h"
 
-#include <typeinfo>
-
 #include <QRegExp>
 #include <QStringList>
 
@@ -32,14 +30,14 @@
 #include "iocommon.h"
 
 FileExporterXML::FileExporterXML()
-        : FileExporter()
+        : FileExporter(), m_cancelFlag(false)
 {
-    // nothing
+    /// nothing
 }
 
 FileExporterXML::~FileExporterXML()
 {
-    // nothing
+    /// nothing
 }
 
 bool FileExporterXML::save(QIODevice *iodevice, const File *bibtexfile, QStringList * /*errorLog*/)
@@ -56,7 +54,7 @@ bool FileExporterXML::save(QIODevice *iodevice, const File *bibtexfile, QStringL
 
     stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
     stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX/KDE4 -->" << endl;
-    stream << "<!-- http://home.gna.org/kbibtex/ -->" << endl;
+    stream << "<!-- https://userbase.kde.org/KBibTeX -->" << endl;
     stream << "<bibliography>" << endl;
 
     for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !m_cancelFlag; ++it)
@@ -80,7 +78,7 @@ bool FileExporterXML::save(QIODevice *iodevice, const QSharedPointer<const Eleme
 
     stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
     stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX/KDE4 -->" << endl;
-    stream << "<!-- http://home.gna.org/kbibtex/ -->" << endl;
+    stream << "<!-- https://userbase.kde.org/KBibTeX -->" << endl;
 
     const bool result = write(stream, element.data());
 
@@ -135,7 +133,7 @@ bool FileExporterXML::writeEntry(QTextStream &stream, const Entry *entry)
             const QSharedPointer<ValueItem> last = *lastIt;
             stream << "  <" << key << "s";
 
-            if (!value.isEmpty() && typeid(PlainText) == typeid(*last)) {
+            if (!value.isEmpty() && PlainText::isPlainText(*last)) {
                 QSharedPointer<const PlainText> pt = internal.last().staticCast<const PlainText>();
                 if (pt->text() == QLatin1String("others")) {
                     internal.erase(internal.end() - 1);
