@@ -20,6 +20,7 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QXmlStreamReader>
+#include <QTimer>
 
 #include <KDebug>
 
@@ -38,6 +39,7 @@ private:
 
 public:
     QSharedPointer<Zotero::API> api;
+    KUrl queuedRequestZoteroUrl;
 
     Private(QSharedPointer<Zotero::API> a, Zotero::Items *parent)
             : p(parent), api(a) {
@@ -61,7 +63,12 @@ public:
         internalUrl.removeQueryItem(queryItemStart);
         internalUrl.addQueryItem(queryItemStart, QString::number(start));
 
-        requestZoteroUrl(internalUrl);
+        if (api->inBackoffMode() && queuedRequestZoteroUrl.isEmpty()) {
+            /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+            queuedRequestZoteroUrl = internalUrl;
+            QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, p, SLOT(singleShotRequestZoteroUrl()));
+        } else
+            requestZoteroUrl(internalUrl);
     }
 };
 
@@ -71,6 +78,11 @@ Items::Items(QSharedPointer<Zotero::API> api, QObject *parent)
     /// nothing
 }
 
+Items::~Items()
+{
+    delete d;
+}
+
 void Items::retrieveItemsByCollection(const QString &collection)
 {
     KUrl url = d->api->baseUrl();
@@ -79,7 +91,12 @@ void Items::retrieveItemsByCollection(const QString &collection)
     else
         url.addPath(QString(QLatin1String("/collections/%1/items")).arg(collection));
     url.addQueryItem(QLatin1String("format"), QLatin1String("bibtex"));
-    d->retrieveItems(url, 0);
+    if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+        /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+        d->queuedRequestZoteroUrl = url;
+        QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+    } else
+        d->retrieveItems(url, 0);
 }
 
 void  Items::retrieveItemsByTag(const QString &tag)
@@ -89,7 +106,12 @@ void  Items::retrieveItemsByTag(const QString &tag)
         url.addQueryItem(QLatin1String("tag"), tag);
     url.addPath(QLatin1String("items"));
     url.addQueryItem(QLatin1String("format"), QLatin1String("bibtex"));
-    d->retrieveItems(url, 0);
+    if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+        /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+        d->queuedRequestZoteroUrl = url;
+        QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+    } else
+        d->retrieveItems(url, 0);
 }
 
 void Items::finishedFetchingItems()
@@ -99,6 +121,18 @@ void Items::finishedFetchingItems()
     bool ok = false;
     const int start = reply->url().queryItemValue(queryItemStart).toInt(&ok);
 
+    if (reply->hasRawHeader("Backoff")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Backoff").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Backoff' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    } else if (reply->hasRawHeader("Retry-After")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Retry-After").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Retry-After' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    }
+
     if (reply->error() == QNetworkReply::NoError && ok) {
         const QString bibTeXcode = QString::fromUtf8(reply->readAll().constData());
         /// Non-empty result?
@@ -127,3 +161,8 @@ void Items::finishedFetchingItems()
         emit stoppedSearch(1); // TODO proper error codes
     }
 }
+
+void Items::singleShotRequestZoteroUrl() {
+    d->retrieveItems(d->queuedRequestZoteroUrl, 0);
+    d->queuedRequestZoteroUrl.clear();
+}
