@@ -35,6 +35,9 @@ public:
     explicit ZoteroBrowser(SearchResults *searchResults, QWidget *parent);
     ~ZoteroBrowser();
 
+public slots:
+    void visibiltyChanged(bool);
+
 signals:
     void itemToShow();
 
@@ -42,8 +45,6 @@ private:
     class Private;
     Private *const d;
 
-    void setupGUI();
-
 private slots:
     void modelReset();
     void collectionDoubleClicked(const QModelIndex &index);
@@ -51,14 +52,20 @@ private slots:
     void showItem(QSharedPointer<Element>);
     void reenableWidget();
     void updateButtons();
-    void applyCredentials();
+    bool applyCredentials();
     void radioButtonsToggled();
+    void groupListChanged();
     void retrieveGroupList();
     void invalidateGroupList();
     void gotGroupList();
 #ifdef HAVE_QTOAUTH // krazy:exclude=cpp
     void getOAuthCredentials();
+#else // HAVE_QTOAUTH
+    void applyManuallyEnteredCredentials();
 #endif // HAVE_QTOAUTH
+    void readOAuthCredentials(bool);
+    void writeOAuthCredentials(bool);
+    void tabChanged(int);
 };
 
 
