@@ -34,6 +34,8 @@ class OpenFileInfoManager;
 
 class DocumentListDelegate : public QStyledItemDelegate
 {
+    Q_OBJECT
+
 private:
     OpenFileInfoManager *ofim;
 
@@ -50,7 +52,7 @@ class DocumentListModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    DocumentListModel(OpenFileInfo::StatusFlag statusFlag, OpenFileInfoManager *openFileInfoManager, QObject *parent = NULL);
+    explicit DocumentListModel(OpenFileInfo::StatusFlag statusFlag, OpenFileInfoManager *openFileInfoManager, QObject *parent = NULL);
     ~DocumentListModel();
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
